@@ -1,60 +1,48 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Driver\PDO\SQLite;
 
 use Doctrine\DBAL\Driver\AbstractSQLiteDriver;
-use Doctrine\DBAL\Driver\API\SQLite\UserDefinedFunctions;
 use Doctrine\DBAL\Driver\PDO\Connection;
 use Doctrine\DBAL\Driver\PDO\Exception;
-use Doctrine\Deprecations\Deprecation;
-use PDO;
+use Doctrine\DBAL\Driver\PDO\Exception\InvalidConfiguration;
+use Doctrine\DBAL\Driver\PDO\PDOConnect;
 use PDOException;
 use SensitiveParameter;
 
 use function array_intersect_key;
+use function is_string;
 
 final class Driver extends AbstractSQLiteDriver
 {
+    use PDOConnect;
+
     /**
-     * {@inheritdoc}
-     *
-     * @return Connection
+     * {@inheritDoc}
      */
     public function connect(
         #[SensitiveParameter]
-        array $params
-    ) {
-        $driverOptions        = $params['driverOptions'] ?? [];
-        $userDefinedFunctions = [];
-
-        if (isset($driverOptions['userDefinedFunctions'])) {
-            Deprecation::trigger(
-                'doctrine/dbal',
-                'https://github.com/doctrine/dbal/pull/5742',
-                'The SQLite-specific driver option "userDefinedFunctions" is deprecated.'
-                    . ' Register function directly on the native connection instead.',
-            );
-
-            $userDefinedFunctions = $driverOptions['userDefinedFunctions'];
-            unset($driverOptions['userDefinedFunctions']);
+        array $params,
+    ): Connection {
+        foreach (['user', 'password'] as $key) {
+            if (isset($params[$key]) && ! is_string($params[$key])) {
+                throw InvalidConfiguration::notAStringOrNull($key, $params[$key]);
+            }
         }
 
         try {
-            $pdo = new PDO(
+            $pdo = $this->doConnect(
                 $this->constructPdoDsn(array_intersect_key($params, ['path' => true, 'memory' => true])),
                 $params['user'] ?? '',
                 $params['password'] ?? '',
-                $driverOptions,
+                $params['driverOptions'] ?? [],
             );
         } catch (PDOException $exception) {
             throw Exception::new($exception);
         }
 
-        UserDefinedFunctions::register(
-            [$pdo, 'sqliteCreateFunction'],
-            $userDefinedFunctions,
-        );
-
         return new Connection($pdo);
     }
 
