@@ -6,14 +6,14 @@ namespace Doctrine\DBAL\Exception;
 
 use Doctrine\DBAL\Exception;
 use LogicException;
+use Throwable;
 
 use function sprintf;
 
-/** @psalm-immutable */
 final class InvalidColumnIndex extends LogicException implements Exception
 {
-    public static function new(int $index): self
+    public static function new(int $index, ?Throwable $previous = null): self
     {
-        return new self(sprintf('Invalid column index "%s".', $index));
+        return new self(sprintf('Invalid column index "%s".', $index), previous: $previous);
     }
 }
