@@ -7,31 +7,28 @@ namespace Doctrine\DBAL\Logging;
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\Middleware\AbstractDriverMiddleware;
 use Psr\Log\LoggerInterface;
+use SensitiveParameter;
 
 final class Driver extends AbstractDriverMiddleware
 {
-    private LoggerInterface $logger;
-
-    /**
-     * @internal This driver can be only instantiated by its middleware.
-     */
-    public function __construct(DriverInterface $driver, LoggerInterface $logger)
+    /** @internal This driver can be only instantiated by its middleware. */
+    public function __construct(DriverInterface $driver, private readonly LoggerInterface $logger)
     {
         parent::__construct($driver);
-
-        $this->logger = $logger;
     }
 
     /**
      * {@inheritDoc}
      */
-    public function connect(array $params)
-    {
+    public function connect(
+        #[SensitiveParameter]
+        array $params,
+    ): Connection {
         $this->logger->info('Connecting with parameters {params}', ['params' => $this->maskPassword($params)]);
 
         return new Connection(
             parent::connect($params),
-            $this->logger
+            $this->logger,
         );
     }
 
@@ -40,16 +37,14 @@ final class Driver extends AbstractDriverMiddleware
      *
      * @return array<string,mixed>
      */
-    private function maskPassword(array $params): array
-    {
+    private function maskPassword(
+        #[SensitiveParameter]
+        array $params,
+    ): array {
         if (isset($params['password'])) {
             $params['password'] = '<redacted>';
         }
 
-        if (isset($params['url'])) {
-            $params['url'] = '<redacted>';
-        }
-
         return $params;
     }
 }
