@@ -10,16 +10,19 @@ use Doctrine\DBAL\LockMode;
 use Doctrine\DBAL\Platforms\Keywords\KeywordList;
 use Doctrine\DBAL\Platforms\Keywords\SQLServerKeywords;
 use Doctrine\DBAL\Platforms\SQLServer\SQL\Builder\SQLServerSelectSQLBuilder;
+use Doctrine\DBAL\Platforms\SQLServer\SQLServerMetadataProvider;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnDiff;
 use Doctrine\DBAL\Schema\Identifier;
 use Doctrine\DBAL\Schema\Index;
+use Doctrine\DBAL\Schema\Name\UnquotedIdentifierFolding;
 use Doctrine\DBAL\Schema\Sequence;
 use Doctrine\DBAL\Schema\SQLServerSchemaManager;
 use Doctrine\DBAL\Schema\TableDiff;
 use Doctrine\DBAL\SQL\Builder\SelectSQLBuilder;
 use Doctrine\DBAL\TransactionIsolationLevel;
 use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\Deprecation;
 use InvalidArgumentException;
 
 use function array_map;
@@ -53,6 +56,11 @@ class SQLServerPlatform extends AbstractPlatform
     /** @internal Should be used only from within the {@see AbstractSchemaManager} class hierarchy. */
     public const OPTION_DEFAULT_CONSTRAINT_NAME = 'default_constraint_name';
 
+    public function __construct()
+    {
+        parent::__construct(UnquotedIdentifierFolding::NONE);
+    }
+
     public function createSelectSQLBuilder(): SelectSQLBuilder
     {
         return new SQLServerSelectSQLBuilder($this);
@@ -177,6 +185,8 @@ class SQLServerPlatform extends AbstractPlatform
      */
     protected function _getCreateTableSQL(string $name, array $columns, array $options = []): array
     {
+        $this->validateCreateTableOptions($options, __METHOD__);
+
         $defaultConstraintsSql = [];
         $commentsSql           = [];
 
@@ -207,13 +217,13 @@ class SQLServerPlatform extends AbstractPlatform
 
         $columnListSql = $this->getColumnDeclarationListSQL($columns);
 
-        if (isset($options['uniqueConstraints']) && ! empty($options['uniqueConstraints'])) {
+        if (! empty($options['uniqueConstraints'])) {
             foreach ($options['uniqueConstraints'] as $definition) {
                 $columnListSql .= ', ' . $this->getUniqueConstraintDeclarationSQL($definition);
             }
         }
 
-        if (isset($options['primary']) && ! empty($options['primary'])) {
+        if (! empty($options['primary'])) {
             $flags = '';
             if (isset($options['primary_index']) && $options['primary_index']->hasFlag('nonclustered')) {
                 $flags = ' NONCLUSTERED';
@@ -234,7 +244,7 @@ class SQLServerPlatform extends AbstractPlatform
 
         $sql = [$query];
 
-        if (isset($options['indexes']) && ! empty($options['indexes'])) {
+        if (! empty($options['indexes'])) {
             foreach ($options['indexes'] as $index) {
                 $sql[] = $this->getCreateIndexSQL($index, $name);
             }
@@ -249,8 +259,16 @@ class SQLServerPlatform extends AbstractPlatform
         return array_merge($sql, $commentsSql, $defaultConstraintsSql);
     }
 
+    /** @deprecated */
     public function getCreatePrimaryKeySQL(Index $index, string $table): string
     {
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6867',
+            '%s() is deprecated.',
+            __METHOD__,
+        );
+
         $sql = 'ALTER TABLE ' . $table . ' ADD PRIMARY KEY';
 
         if ($index->hasFlag('nonclustered')) {
@@ -278,6 +296,8 @@ class SQLServerPlatform extends AbstractPlatform
      * as column comments are stored in the same property there when
      * specifying a column's "Description" attribute.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @param string $tableName  The quoted table name to which the column belongs.
      * @param string $columnName The quoted column name to create the comment for.
      * @param string $comment    The column's comment.
@@ -305,6 +325,8 @@ class SQLServerPlatform extends AbstractPlatform
     /**
      * Returns the SQL snippet for declaring a default constraint.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @param mixed[] $column Column definition.
      */
     protected function getDefaultConstraintDeclarationSQL(array $column): string
@@ -524,7 +546,7 @@ class SQLServerPlatform extends AbstractPlatform
             );
         }
 
-        return 'DROP CONSTRAINT ' . $this->quoteIdentifier(
+        return 'DROP CONSTRAINT ' . $this->quoteSingleIdentifier(
             $column->getPlatformOption(self::OPTION_DEFAULT_CONSTRAINT_NAME),
         );
     }
@@ -567,6 +589,8 @@ class SQLServerPlatform extends AbstractPlatform
      * as column comments are stored in the same property there when
      * specifying a column's "Description" attribute.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @param string $tableName  The quoted table name to which the column belongs.
      * @param string $columnName The quoted column name to alter the comment for.
      * @param string $comment    The column's comment.
@@ -602,6 +626,8 @@ class SQLServerPlatform extends AbstractPlatform
      * as column comments are stored in the same property there when
      * specifying a column's "Description" attribute.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @param string $tableName  The quoted table name to which the column belongs.
      * @param string $columnName The quoted column name to drop the comment for.
      */
@@ -651,15 +677,16 @@ class SQLServerPlatform extends AbstractPlatform
      */
     private function getRenameSQL(string ...$arguments): string
     {
-        return 'EXEC sp_rename '
-             . implode(', ', array_map(function (string $argument): string {
-                return 'N' . $this->quoteStringLiteral($argument);
-             }, $arguments));
+        return $this->getExecSQL('sp_rename', ...array_map(function (string $argument): string {
+            return $this->quoteNationalStringLiteral($argument);
+        }, $arguments));
     }
 
     /**
      * Returns the SQL statement for adding an extended property to a database object.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @link http://msdn.microsoft.com/en-us/library/ms180047%28v=sql.90%29.aspx
      *
      * @param string      $name       The name of the property to add.
@@ -681,19 +708,28 @@ class SQLServerPlatform extends AbstractPlatform
         ?string $level2Type = null,
         ?string $level2Name = null,
     ): string {
-        return 'EXEC sp_addextendedproperty ' .
-            'N' . $this->quoteStringLiteral($name) . ', N' . $this->quoteStringLiteral($value ?? '') . ', ' .
-            'N' . $this->quoteStringLiteral($level0Type ?? '') . ', ' . $level0Name . ', ' .
-            'N' . $this->quoteStringLiteral($level1Type ?? '') . ', ' . $level1Name .
-            ($level2Type !== null || $level2Name !== null
-                ? ', N' . $this->quoteStringLiteral($level2Type ?? '') . ', ' . $level2Name
-                : ''
-            );
+        $arguments = [
+            $this->quoteNationalStringLiteral($name),
+            $this->quoteNationalStringLiteral($value ?? ''),
+            $this->quoteNationalStringLiteral($level0Type ?? ''),
+            $level0Name ?? '',
+            $this->quoteNationalStringLiteral($level1Type ?? ''),
+            $level1Name ?? '',
+        ];
+
+        if ($level2Type !== null || $level2Name !== null) {
+            $arguments[] = $this->quoteNationalStringLiteral($level2Type ?? '');
+            $arguments[] = $level2Name ?? '';
+        }
+
+        return $this->getExecSQL('sp_addextendedproperty', ...$arguments);
     }
 
     /**
      * Returns the SQL statement for dropping an extended property from a database object.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @link http://technet.microsoft.com/en-gb/library/ms178595%28v=sql.90%29.aspx
      *
      * @param string      $name       The name of the property to drop.
@@ -713,19 +749,27 @@ class SQLServerPlatform extends AbstractPlatform
         ?string $level2Type = null,
         ?string $level2Name = null,
     ): string {
-        return 'EXEC sp_dropextendedproperty ' .
-            'N' . $this->quoteStringLiteral($name) . ', ' .
-            'N' . $this->quoteStringLiteral($level0Type ?? '') . ', ' . $level0Name . ', ' .
-            'N' . $this->quoteStringLiteral($level1Type ?? '') . ', ' . $level1Name .
-            ($level2Type !== null || $level2Name !== null
-                ? ', N' . $this->quoteStringLiteral($level2Type ?? '') . ', ' . $level2Name
-                : ''
-            );
+        $arguments = [
+            $this->quoteNationalStringLiteral($name),
+            $this->quoteNationalStringLiteral($level0Type ?? ''),
+            $level0Name ?? '',
+            $this->quoteNationalStringLiteral($level1Type ?? ''),
+            $level1Name ?? '',
+        ];
+
+        if ($level2Type !== null || $level2Name !== null) {
+            $arguments[] = $this->quoteNationalStringLiteral($level2Type ?? '');
+            $arguments[] = $level2Name ?? '';
+        }
+
+        return $this->getExecSQL('sp_dropextendedproperty', ...$arguments);
     }
 
     /**
      * Returns the SQL statement for updating an extended property of a database object.
      *
+     * @internal The method should be only used by the {@see SQLServerPlatform} class.
+     *
      * @link http://msdn.microsoft.com/en-us/library/ms186885%28v=sql.90%29.aspx
      *
      * @param string      $name       The name of the property to update.
@@ -747,14 +791,37 @@ class SQLServerPlatform extends AbstractPlatform
         ?string $level2Type = null,
         ?string $level2Name = null,
     ): string {
-        return 'EXEC sp_updateextendedproperty ' .
-            'N' . $this->quoteStringLiteral($name) . ', N' . $this->quoteStringLiteral($value ?? '') . ', ' .
-            'N' . $this->quoteStringLiteral($level0Type ?? '') . ', ' . $level0Name . ', ' .
-            'N' . $this->quoteStringLiteral($level1Type ?? '') . ', ' . $level1Name .
-            ($level2Type !== null || $level2Name !== null
-                ? ', N' . $this->quoteStringLiteral($level2Type ?? '') . ', ' . $level2Name
-                : ''
-            );
+        $arguments = [
+            $this->quoteNationalStringLiteral($name),
+            $this->quoteNationalStringLiteral($value ?? ''),
+            $this->quoteNationalStringLiteral($level0Type ?? ''),
+            $level0Name ?? '',
+            $this->quoteNationalStringLiteral($level1Type ?? ''),
+            $level1Name ?? '',
+        ];
+
+        if ($level2Type !== null || $level2Name !== null) {
+            $arguments[] = $this->quoteNationalStringLiteral($level2Type ?? '');
+            $arguments[] = $level2Name ?? '';
+        }
+
+        return $this->getExecSQL('sp_updateextendedproperty', ...$arguments);
+    }
+
+    /**
+     * Returns the SQL statement that will execute the given stored procedure with the given arguments.
+     *
+     * @param string $procedureName The name of the stored procedure to execute.
+     * @param string ...$arguments  The SQL fragments representing the arguments to pass to the stored procedure.
+     */
+    private function getExecSQL(string $procedureName, string ...$arguments): string
+    {
+        return 'EXEC ' . $this->quoteSingleIdentifier($procedureName) . ' ' . implode(', ', $arguments);
+    }
+
+    private function quoteNationalStringLiteral(string $value): string
+    {
+        return 'N' . $this->quoteStringLiteral($value);
     }
 
     public function getEmptyIdentityInsertSQL(string $quotedTableName, string $quotedIdentifierColumnName): string
@@ -935,7 +1002,11 @@ class SQLServerPlatform extends AbstractPlatform
      */
     protected function _getCommonIntegerTypeDeclarationSQL(array $column): string
     {
-        return ! empty($column['autoincrement']) ? ' IDENTITY' : '';
+        if (! empty($column['autoincrement'])) {
+            return ' IDENTITY';
+        }
+
+        return '';
     }
 
     /**
@@ -1110,6 +1181,13 @@ class SQLServerPlatform extends AbstractPlatform
     {
         // RESTRICT is not supported, therefore falling back to NO ACTION.
         if (strtoupper($action) === 'RESTRICT') {
+            Deprecation::trigger(
+                'doctrine/dbal',
+                'https://github.com/doctrine/dbal/pull/6707',
+                'Relying on automatic conversion of RESTRICT to NO ACTION for SQL Server is deprecated.'
+                    . ' Use NO ACTION explicitly instead.',
+            );
+
             return 'NO ACTION';
         }
 
@@ -1126,8 +1204,16 @@ class SQLServerPlatform extends AbstractPlatform
         };
     }
 
+    /** @deprecated */
     protected function createReservedKeywordsList(): KeywordList
     {
+        Deprecation::triggerIfCalledFromOutside(
+            'doctrine/dbal',
+            'https://github.com/doctrine/dbal/pull/6607',
+            '%s is deprecated.',
+            __METHOD__,
+        );
+
         return new SQLServerKeywords();
     }
 
@@ -1191,9 +1277,14 @@ class SQLServerPlatform extends AbstractPlatform
             === $this->getDefaultValueDeclarationSQL($column2->toArray());
     }
 
+    /**
+     * The <code>[</code> character is used in SQL Server's extended pattern syntax to define character ranges or sets.
+     *
+     * @link https://learn.microsoft.com/en-us/sql/t-sql/language-elements/like-transact-sql#pattern
+     */
     protected function getLikeWildcardCharacters(): string
     {
-        return parent::getLikeWildcardCharacters() . '[]^';
+        return parent::getLikeWildcardCharacters() . '[';
     }
 
     protected function getCommentOnTableSQL(string $tableName, string $comment): string
@@ -1242,6 +1333,11 @@ class SQLServerPlatform extends AbstractPlatform
         return true;
     }
 
+    public function createMetadataProvider(Connection $connection): SQLServerMetadataProvider
+    {
+        return new SQLServerMetadataProvider($connection, $this);
+    }
+
     public function createSchemaManager(Connection $connection): SQLServerSchemaManager
     {
         return new SQLServerSchemaManager($connection, $this);
