@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Schema;
 
-use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Platforms\DB2Platform;
 use Doctrine\DBAL\Result;
 use Doctrine\DBAL\Types\Type;
@@ -13,6 +12,7 @@ use Doctrine\DBAL\Types\Types;
 use function array_change_key_case;
 use function implode;
 use function preg_match;
+use function sprintf;
 use function str_replace;
 use function strpos;
 use function strtolower;
@@ -22,7 +22,9 @@ use function substr;
 use const CASE_LOWER;
 
 /**
- * IBM Db2 Schema Manager.
+ * Db2 Schema Manager.
+ *
+ * @link https://www.ibm.com/docs/en/db2/11.5?topic=sql-catalog-views
  *
  * @extends AbstractSchemaManager<DB2Platform>
  */
@@ -30,8 +32,6 @@ class DB2SchemaManager extends AbstractSchemaManager
 {
     /**
      * {@inheritDoc}
-     *
-     * @throws Exception
      */
     protected function _getPortableTableColumnDefinition(array $tableColumn): Column
     {
@@ -83,15 +83,13 @@ class DB2SchemaManager extends AbstractSchemaManager
 
         $options = [
             'length'          => $length,
-            'unsigned'        => false,
             'fixed'           => $fixed,
             'default'         => $default,
             'autoincrement'   => (bool) $tableColumn['autoincrement'],
             'notnull'         => $tableColumn['nulls'] === 'N',
-            'platformOptions' => [],
         ];
 
-        if (isset($tableColumn['comment'])) {
+        if ($tableColumn['comment'] !== null) {
             $options['comment'] = $tableColumn['comment'];
         }
 
@@ -104,6 +102,8 @@ class DB2SchemaManager extends AbstractSchemaManager
     }
 
     /**
+     * @deprecated Use the schema name and the unqualified table name separately instead.
+     *
      * {@inheritDoc}
      */
     protected function _getPortableTableDefinition(array $table): string
@@ -116,14 +116,14 @@ class DB2SchemaManager extends AbstractSchemaManager
     /**
      * {@inheritDoc}
      */
-    protected function _getPortableTableIndexesList(array $tableIndexes, string $tableName): array
+    protected function _getPortableTableIndexesList(array $rows, string $tableName): array
     {
-        foreach ($tableIndexes as &$tableIndexRow) {
-            $tableIndexRow            = array_change_key_case($tableIndexRow, CASE_LOWER);
-            $tableIndexRow['primary'] = (bool) $tableIndexRow['primary'];
+        foreach ($rows as &$row) {
+            $row            = array_change_key_case($row, CASE_LOWER);
+            $row['primary'] = (bool) $row['primary'];
         }
 
-        return parent::_getPortableTableIndexesList($tableIndexes, $tableName);
+        return parent::_getPortableTableIndexesList($rows, $tableName);
     }
 
     /**
@@ -143,11 +143,11 @@ class DB2SchemaManager extends AbstractSchemaManager
     /**
      * {@inheritDoc}
      */
-    protected function _getPortableTableForeignKeysList(array $tableForeignKeys): array
+    protected function _getPortableTableForeignKeysList(array $rows): array
     {
         $foreignKeys = [];
 
-        foreach ($tableForeignKeys as $tableForeignKey) {
+        foreach ($rows as $tableForeignKey) {
             $tableForeignKey = array_change_key_case($tableForeignKey, CASE_LOWER);
 
             if (! isset($foreignKeys[$tableForeignKey['index_name']])) {
@@ -187,6 +187,7 @@ class DB2SchemaManager extends AbstractSchemaManager
         return new View($view['name'], $sql);
     }
 
+    /** @deprecated Use {@see Identifier::toNormalizedValue()} instead. */
     protected function normalizeName(string $name): string
     {
         $identifier = new Identifier($name);
@@ -197,10 +198,10 @@ class DB2SchemaManager extends AbstractSchemaManager
     protected function selectTableNames(string $databaseName): Result
     {
         $sql = <<<'SQL'
-SELECT NAME
-FROM SYSIBM.SYSTABLES
+SELECT TABNAME AS NAME
+FROM SYSCAT.TABLES
 WHERE TYPE = 'T'
-  AND CREATOR = ?
+  AND TABSCHEMA = ?
 SQL;
 
         return $this->connection->executeQuery($sql, [$databaseName]);
@@ -208,13 +209,18 @@ SQL;
 
     protected function selectTableColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT';
+        $conditions = ['C.TABSCHEMA = ?'];
+        $params     = [$databaseName];
 
-        if ($tableName === null) {
-            $sql .= ' C.TABNAME AS NAME,';
+        if ($tableName !== null) {
+            $conditions[] = 'C.TABNAME = ?';
+            $params[]     = $tableName;
         }
 
-        $sql .= <<<'SQL'
+        $sql = sprintf(
+            <<<'SQL'
+SELECT
+       C.TABNAME AS NAME,
        C.COLNAME,
        C.TYPENAME,
        C.CODEPAGE,
@@ -231,30 +237,30 @@ FROM SYSCAT.COLUMNS C
          JOIN SYSCAT.TABLES AS T
               ON T.TABSCHEMA = C.TABSCHEMA
                   AND T.TABNAME = C.TABNAME
-SQL;
-
-        $conditions = ['C.TABSCHEMA = ?', "T.TYPE = 'T'"];
-        $params     = [$databaseName];
-
-        if ($tableName !== null) {
-            $conditions[] = 'C.TABNAME = ?';
-            $params[]     = $tableName;
-        }
-
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY C.TABNAME, C.COLNO';
+ WHERE %s
+   AND T.TYPE = 'T'
+ORDER BY C.TABNAME, C.COLNO
+SQL,
+            implode(' AND ', $conditions),
+        );
 
         return $this->connection->executeQuery($sql, $params);
     }
 
     protected function selectIndexColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT';
+        $conditions = ['IDX.TABSCHEMA = ?'];
+        $params     = [$databaseName];
 
-        if ($tableName === null) {
-            $sql .= ' IDX.TABNAME AS NAME,';
+        if ($tableName !== null) {
+            $conditions[] = 'IDX.TABNAME = ?';
+            $params[]     = $tableName;
         }
 
-        $sql .= <<<'SQL'
+        $sql = sprintf(
+            <<<'SQL'
+      SELECT
+             IDX.TABNAME AS NAME,
              IDX.INDNAME AS KEY_NAME,
              IDXCOL.COLNAME AS COLUMN_NAME,
              CASE
@@ -270,30 +276,32 @@ SQL;
           ON IDX.TABSCHEMA = T.TABSCHEMA AND IDX.TABNAME = T.TABNAME
         JOIN SYSCAT.INDEXCOLUSE AS IDXCOL
           ON IDX.INDSCHEMA = IDXCOL.INDSCHEMA AND IDX.INDNAME = IDXCOL.INDNAME
-SQL;
-
-        $conditions = ['IDX.TABSCHEMA = ?', "T.TYPE = 'T'"];
-        $params     = [$databaseName];
-
-        if ($tableName !== null) {
-            $conditions[] = 'IDX.TABNAME = ?';
-            $params[]     = $tableName;
-        }
-
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY IDX.INDNAME, IDXCOL.COLSEQ';
+       WHERE %s
+         AND T.TYPE = 'T'
+    ORDER BY IDX.TABNAME,
+             IDX.INDNAME,
+             IDXCOL.COLSEQ
+SQL,
+            implode(' AND ', $conditions),
+        );
 
         return $this->connection->executeQuery($sql, $params);
     }
 
     protected function selectForeignKeyColumns(string $databaseName, ?string $tableName = null): Result
     {
-        $sql = 'SELECT';
+        $conditions = ['R.TABSCHEMA = ?'];
+        $params     = [$databaseName];
 
-        if ($tableName === null) {
-            $sql .= ' R.TABNAME AS NAME,';
+        if ($tableName !== null) {
+            $conditions[] = 'R.TABNAME = ?';
+            $params[]     = $tableName;
         }
 
-        $sql .= <<<'SQL'
+        $sql = sprintf(
+            <<<'SQL'
+      SELECT
+             R.TABNAME AS NAME,
              FKCOL.COLNAME AS LOCAL_COLUMN,
              R.REFTABNAME AS FOREIGN_TABLE,
              PKCOL.COLNAME AS FOREIGN_COLUMN,
@@ -319,17 +327,14 @@ SQL;
                   AND PKCOL.TABSCHEMA = R.REFTABSCHEMA
                   AND PKCOL.TABNAME = R.REFTABNAME
                   AND PKCOL.COLSEQ = FKCOL.COLSEQ
-SQL;
-
-        $conditions = ['R.TABSCHEMA = ?', "T.TYPE = 'T'"];
-        $params     = [$databaseName];
-
-        if ($tableName !== null) {
-            $conditions[] = 'R.TABNAME = ?';
-            $params[]     = $tableName;
-        }
-
-        $sql .= ' WHERE ' . implode(' AND ', $conditions) . ' ORDER BY R.CONSTNAME, FKCOL.COLSEQ';
+      WHERE %s
+        AND T.TYPE = 'T'
+   ORDER BY R.TABNAME,
+            R.CONSTNAME,
+            FKCOL.COLSEQ
+SQL,
+            implode(' AND ', $conditions),
+        );
 
         return $this->connection->executeQuery($sql, $params);
     }
@@ -339,31 +344,29 @@ SQL;
      */
     protected function fetchTableOptionsByTable(string $databaseName, ?string $tableName = null): array
     {
-        $sql = 'SELECT NAME, REMARKS';
-
-        $conditions = [];
-        $params     = [];
+        $conditions = ['TABSCHEMA = ?'];
+        $params     = [$databaseName];
 
         if ($tableName !== null) {
-            $conditions[] = 'NAME = ?';
+            $conditions[] = 'TABNAME = ?';
             $params[]     = $tableName;
         }
 
-        $sql .= ' FROM SYSIBM.SYSTABLES';
-
-        if ($conditions !== []) {
-            $sql .= ' WHERE ' . implode(' AND ', $conditions);
-        }
-
-        /** @var array<string,array<string,mixed>> $metadata */
-        $metadata = $this->connection->executeQuery($sql, $params)
-            ->fetchAllAssociativeIndexed();
+        $sql = sprintf(
+            <<<'SQL'
+      SELECT TABNAME,
+             REMARKS
+        FROM SYSCAT.TABLES
+      WHERE %s
+        AND TYPE = 'T'
+   ORDER BY TABNAME
+SQL,
+            implode(' AND ', $conditions),
+        );
 
         $tableOptions = [];
-        foreach ($metadata as $table => $data) {
-            $data = array_change_key_case($data, CASE_LOWER);
-
-            $tableOptions[$table] = ['comment' => $data['remarks']];
+        foreach ($this->connection->iterateKeyValue($sql, $params) as $table => $remarks) {
+            $tableOptions[$table] = ['comment' => $remarks];
         }
 
         return $tableOptions;
