@@ -10,20 +10,15 @@ use Doctrine\DBAL\Platforms\AbstractPlatform;
 final class AsciiStringType extends StringType
 {
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
     public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
     {
         return $platform->getAsciiStringTypeDeclarationSQL($column);
     }
 
-    public function getBindingType(): int
+    public function getBindingType(): ParameterType
     {
         return ParameterType::ASCII;
     }
-
-    public function getName(): string
-    {
-        return Types::ASCII_STRING;
-    }
 }
