@@ -1,9 +1,10 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\Deprecations\Deprecation;
 
 use function count;
 use function explode;
@@ -20,21 +21,14 @@ use function stream_get_contents;
 class SimpleArrayType extends Type
 {
     /**
-     * {@inheritdoc}
+     * {@inheritDoc}
      */
-    public function getSQLDeclaration(array $column, AbstractPlatform $platform)
+    public function getSQLDeclaration(array $column, AbstractPlatform $platform): string
     {
         return $platform->getClobTypeDeclarationSQL($column);
     }
 
-    /**
-     * {@inheritdoc}
-     *
-     * @param mixed $value
-     *
-     * @return string|null
-     */
-    public function convertToDatabaseValue($value, AbstractPlatform $platform)
+    public function convertToDatabaseValue(mixed $value, AbstractPlatform $platform): ?string
     {
         if (! is_array($value) || count($value) === 0) {
             return null;
@@ -43,14 +37,8 @@ class SimpleArrayType extends Type
         return implode(',', $value);
     }
 
-    /**
-     * {@inheritdoc}
-     *
-     * @param mixed $value
-     *
-     * @return list<string>
-     */
-    public function convertToPHPValue($value, AbstractPlatform $platform)
+    /** @return list<string> */
+    public function convertToPHPValue(mixed $value, AbstractPlatform $platform): array
     {
         if ($value === null) {
             return [];
@@ -60,29 +48,4 @@ class SimpleArrayType extends Type
 
         return explode(',', $value);
     }
-
-    /**
-     * {@inheritdoc}
-     */
-    public function getName()
-    {
-        return Types::SIMPLE_ARRAY;
-    }
-
-    /**
-     * {@inheritdoc}
-     *
-     * @deprecated
-     */
-    public function requiresSQLCommentHint(AbstractPlatform $platform)
-    {
-        Deprecation::triggerIfCalledFromOutside(
-            'doctrine/dbal',
-            'https://github.com/doctrine/dbal/pull/5509',
-            '%s is deprecated.',
-            __METHOD__,
-        );
-
-        return true;
-    }
 }
