@@ -44,7 +44,9 @@ abstract class Type
         Types::GUID                 => GuidType::class,
         Types::INTEGER              => IntegerType::class,
         Types::JSON                 => JsonType::class,
+        Types::JSON_OBJECT          => JsonType::class,
         Types::JSONB                => JsonbType::class,
+        Types::JSONB_OBJECT         => JsonbType::class,
         Types::SIMPLE_ARRAY         => SimpleArrayType::class,
         Types::SMALLFLOAT           => SmallFloatType::class,
         Types::SMALLINT             => SmallIntType::class,
