@@ -1,13 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Driver\OCI8;
 
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\OCI8\Driver;
 use Doctrine\DBAL\Driver\OCI8\Exception\InvalidConfiguration;
 use Doctrine\DBAL\Tests\Driver\AbstractOracleDriverTestCase;
+use PHPUnit\Framework\Attributes\RequiresPhpExtension;
 
-/** @requires extension oci8 */
+#[RequiresPhpExtension('oci8')]
 class DriverTest extends AbstractOracleDriverTestCase
 {
     public function testPersistentAndExclusiveAreMutuallyExclusive(): void
