@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Connection;
 
 use Doctrine\DBAL\Exception\ConnectionLost;
@@ -16,7 +18,7 @@ class ConnectionLostTest extends FunctionalTestCase
             return;
         }
 
-        $this->markTestSkipped('Currently only supported with MySQL');
+        self::markTestSkipped('Currently only supported with MySQL');
     }
 
     public function testConnectionLost(): void
@@ -29,10 +31,10 @@ class ConnectionLostTest extends FunctionalTestCase
             ->getDummySelectSQL();
 
         try {
-            // in addition to the error, PHP 7 will generate a warning that needs to be
+            // in addition to the error, MYSQLI_REPORT_OFF will generate a warning that needs to be
             // suppressed in order to not let PHPUnit handle it before the actual error
             @$this->connection->executeQuery($query);
-        } catch (ConnectionLost $e) {
+        } catch (ConnectionLost) {
             self::assertEquals(1, $this->connection->fetchOne($query));
 
             return;
