@@ -4,9 +4,12 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Driver;
 
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\PrimaryKeyConstraint;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
+use Doctrine\DBAL\Types\Types;
 
 class DBAL6024Test extends FunctionalTestCase
 {
@@ -21,13 +24,26 @@ class DBAL6024Test extends FunctionalTestCase
 
     public function testDropPrimaryKey(): void
     {
-        $table = new Table('mytable');
-        $table->addColumn('id', 'integer');
-        $table->setPrimaryKey(['id']);
+        $table = Table::editor()
+            ->setUnquotedName('mytable')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+            )
+            ->setPrimaryKeyConstraint(
+                PrimaryKeyConstraint::editor()
+                    ->setUnquotedColumnNames('id')
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
 
-        $newTable = clone $table;
-        $newTable->dropPrimaryKey();
+        $newTable = $table->edit()
+            ->dropPrimaryKeyConstraint()
+            ->create();
 
         $schemaManager = $this->connection->createSchemaManager();
         $diff          = $schemaManager->createComparator()->compareTables($table, $newTable);
@@ -38,7 +54,7 @@ class DBAL6024Test extends FunctionalTestCase
         }
 
         $validationSchema = $schemaManager->introspectSchema();
-        $validationTable  = $validationSchema->getTable($table->getName());
+        $validationTable  = $validationSchema->getTable($table->getObjectName()->toString());
 
         self::assertNull($validationTable->getPrimaryKey());
     }
