@@ -9,22 +9,16 @@ use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Types;
 use Error;
-use ErrorException;
 use Generator;
 use PgSql\Connection as PgSqlConnection;
+use PHPUnit\Framework\Attributes\DataProvider;
 
-use function array_slice;
 use function assert;
 use function chr;
-use function func_get_args;
-use function is_resource;
 use function pg_query;
 use function pg_result_status;
-use function restore_error_handler;
-use function set_error_handler;
 
 use const PGSQL_TUPLES_OK;
-use const PHP_VERSION_ID;
 
 class ResultTest extends FunctionalTestCase
 {
@@ -47,13 +41,12 @@ class ResultTest extends FunctionalTestCase
         parent::tearDown();
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchAssociative(string $postgresType, $expectedValue, string $dbalType): void
-    {
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchAssociative(
+        string $postgresType,
+        mixed $expectedValue,
+        string $dbalType,
+    ): void {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
         $result = $this->connection->fetchAssociative(
@@ -64,13 +57,12 @@ class ResultTest extends FunctionalTestCase
         self::assertSame(['my_value' => $expectedValue, 'my_null' => null], $result);
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchAllAssociative(string $postgresType, $expectedValue, string $dbalType): void
-    {
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchAllAssociative(
+        string $postgresType,
+        mixed $expectedValue,
+        string $dbalType,
+    ): void {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
         $result = $this->connection->fetchAllAssociative(
@@ -81,12 +73,8 @@ class ResultTest extends FunctionalTestCase
         self::assertSame([['my_value' => $expectedValue, 'my_null' => null]], $result);
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchNumeric(string $postgresType, $expectedValue, string $dbalType): void
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchNumeric(string $postgresType, mixed $expectedValue, string $dbalType): void
     {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
@@ -98,13 +86,12 @@ class ResultTest extends FunctionalTestCase
         self::assertSame([$expectedValue, null], $result);
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchAllNumeric(string $postgresType, $expectedValue, string $dbalType): void
-    {
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchAllNumeric(
+        string $postgresType,
+        mixed $expectedValue,
+        string $dbalType,
+    ): void {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
         $result = $this->connection->fetchAllNumeric(
@@ -115,12 +102,8 @@ class ResultTest extends FunctionalTestCase
         self::assertSame([[$expectedValue, null]], $result);
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchOne(string $postgresType, $expectedValue, string $dbalType): void
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchOne(string $postgresType, mixed $expectedValue, string $dbalType): void
     {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
@@ -132,13 +115,12 @@ class ResultTest extends FunctionalTestCase
         self::assertSame($expectedValue, $result);
     }
 
-    /**
-     * @param mixed $expectedValue
-     *
-     * @dataProvider typedValueProvider
-     */
-    public function testTypeConversionFetchFirstColumn(string $postgresType, $expectedValue, string $dbalType): void
-    {
+    #[DataProvider('typedValueProvider')]
+    public function testTypeConversionFetchFirstColumn(
+        string $postgresType,
+        mixed $expectedValue,
+        string $dbalType,
+    ): void {
         $id = $this->prepareTypesTestTable($postgresType, $expectedValue, $dbalType);
 
         $result = $this->connection->fetchFirstColumn(
@@ -149,7 +131,7 @@ class ResultTest extends FunctionalTestCase
         self::assertSame([$expectedValue], $result);
     }
 
-    /** @psalm-return Generator<string, array{string, mixed, (Types::*)}> */
+    /** @phpstan-return Generator<string, array{string, mixed, (Types::*)}> */
     public static function typedValueProvider(): Generator
     {
         yield 'integer' => ['INTEGER', 4711, Types::INTEGER];
@@ -161,15 +143,16 @@ class ResultTest extends FunctionalTestCase
         yield 'text' => ['TEXT', 'some value', Types::STRING];
         yield 'boolean true' => ['BOOLEAN', true, Types::BOOLEAN];
         yield 'boolean false' => ['BOOLEAN', false, Types::BOOLEAN];
-        yield 'float' => ['REAL', 47.11, Types::FLOAT];
-        yield 'negative float with exponent' => ['REAL', -8.15e10, Types::FLOAT];
+        yield 'float' => ['DOUBLE PRECISION', 47.11, Types::FLOAT];
+        yield 'real' => ['REAL', 47.11, Types::SMALLFLOAT];
+        yield 'negative float with exponent' => ['DOUBLE PRECISION', -8.15e10, Types::FLOAT];
+        yield 'negative real with exponent' => ['REAL', -8.15e5, Types::SMALLFLOAT];
         yield 'double' => ['DOUBLE PRECISION', 47.11, Types::FLOAT];
         yield 'decimal' => ['NUMERIC (6, 2)', '47.11', Types::DECIMAL];
         yield 'binary' => ['BYTEA', chr(0x8b), Types::BINARY];
     }
 
-    /** @param mixed $expectedValue */
-    private function prepareTypesTestTable(string $postgresType, $expectedValue, string $dbalType): int
+    private function prepareTypesTestTable(string $postgresType, mixed $expectedValue, string $dbalType): int
     {
         $sql = <<< SQL
             CREATE TABLE types_test (
@@ -241,7 +224,7 @@ class ResultTest extends FunctionalTestCase
     public function testResultIsFreedOnDestruct(): void
     {
         $pgsqlConnection = $this->connection->getNativeConnection();
-        assert($pgsqlConnection instanceof PgSqlConnection || is_resource($pgsqlConnection));
+        assert($pgsqlConnection instanceof PgSqlConnection);
         $pgsqlResult = pg_query($pgsqlConnection, 'SELECT 1');
         assert($pgsqlResult !== false);
 
@@ -249,22 +232,9 @@ class ResultTest extends FunctionalTestCase
 
         new Result($pgsqlResult);
 
-        set_error_handler(static function (int $severity, string $message): void {
-            throw new ErrorException($message, 0, $severity, ...array_slice(func_get_args(), 2, 2));
-        });
+        $this->expectException(Error::class);
+        $this->expectExceptionMessage('PostgreSQL result has already been closed');
 
-        try {
-            if (PHP_VERSION_ID >= 80100) {
-                $this->expectException(Error::class);
-                $this->expectExceptionMessage('PostgreSQL result has already been closed');
-            } else {
-                $this->expectException(ErrorException::class);
-                $this->expectExceptionMessage('supplied resource is not a valid PostgreSQL result resource');
-            }
-
-            pg_result_status($pgsqlResult);
-        } finally {
-            restore_error_handler();
-        }
+        pg_result_status($pgsqlResult);
     }
 }
