@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Platform;
 
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Types;
@@ -14,20 +15,34 @@ class AddColumnWithDefaultTest extends FunctionalTestCase
     {
         $schemaManager = $this->connection->createSchemaManager();
 
-        $table = new Table('add_default_test');
+        $table = Table::editor()
+            ->setUnquotedName('add_default_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('original_field')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(8)
+                    ->create(),
+            )
+            ->create();
 
-        $table->addColumn('original_field', Types::STRING, ['length' => 8]);
         $this->dropAndCreateTable($table);
 
         $this->connection->executeStatement("INSERT INTO add_default_test (original_field) VALUES ('one')");
 
-        $table->addColumn('new_field', Types::STRING, [
-            'length' => 8,
-            'default' => 'DEFAULT',
-        ]);
+        $table = $table->edit()
+            ->addColumn(
+                Column::editor()
+                    ->setUnquotedName('new_field')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(8)
+                    ->setDefaultValue('DEFAULT')
+                    ->create(),
+            )
+            ->create();
 
         $diff = $schemaManager->createComparator()->compareTables(
-            $schemaManager->introspectTable('add_default_test'),
+            $schemaManager->introspectTableByUnquotedName('add_default_test'),
             $table,
         );
 
