@@ -9,6 +9,17 @@ use Doctrine\DBAL\Tests\TestUtil;
 
 class ParserTest extends FunctionalTestCase
 {
+    public function testMySQLEscaping(): void
+    {
+        if (! TestUtil::isDriverOneOf('mysqli', 'pdo_mysql')) {
+            self::markTestSkipped('This test requires the mysqli or pdo_mysql driver');
+        }
+
+        $result = $this->connection->fetchNumeric("SELECT '\'?', :parameter", ['parameter' => 'value']);
+
+        self::assertEquals(["'?", 'value'], $result);
+    }
+
     public function testPostgreSQLJSONBQuestionOperator(): void
     {
         if (! TestUtil::isDriverOneOf('pdo_pgsql')) {
