@@ -4,7 +4,6 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Schema;
 
-use DateTime;
 use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Exception\DatabaseRequired;
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
@@ -12,6 +11,7 @@ use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\MariaDBPlatform;
 use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\ColumnEditor;
+use Doctrine\DBAL\Schema\DefaultExpression\CurrentTimestamp;
 use Doctrine\DBAL\Schema\Index;
 use Doctrine\DBAL\Schema\Index\IndexedColumn;
 use Doctrine\DBAL\Schema\Index\IndexType;
@@ -71,9 +71,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $indexes = $this->schemaManager->listTableIndexes('fulltext_index');
-        self::assertArrayHasKey('f_index', $indexes);
-        $this->assertIndexEquals($index, $indexes['f_index']);
+        $this->assertIndexListEquals(
+            [$index],
+            $this->schemaManager->introspectTableIndexesByUnquotedName('fulltext_index'),
+        );
     }
 
     public function testSpatialIndex(): void
@@ -104,9 +105,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         // see https://github.com/doctrine/dbal/issues/4983
         $this->markConnectionNotReusable();
 
-        $indexes = $this->schemaManager->listTableIndexes('spatial_index');
-        self::assertArrayHasKey('s_index', $indexes);
-        $this->assertIndexEquals($index, $indexes['s_index']);
+        $this->assertIndexListEquals(
+            [$index],
+            $this->schemaManager->introspectTableIndexesByUnquotedName('spatial_index'),
+        );
     }
 
     public function testIndexWithLength(): void
@@ -132,9 +134,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $indexes = $this->schemaManager->listTableIndexes('index_length');
-        self::assertArrayHasKey('text_index', $indexes);
-        $this->assertIndexEquals($index, $indexes['text_index']);
+        $this->assertIndexListEquals(
+            [$index],
+            $this->schemaManager->introspectTableIndexesByUnquotedName('index_length'),
+        );
     }
 
     public function testDropPrimaryKeyWithAutoincrementColumn(): void
@@ -174,7 +177,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table = $this->schemaManager->introspectTable('drop_primary_key');
+        $table = $this->schemaManager->introspectTableByUnquotedName('drop_primary_key');
 
         self::assertNull($table->getPrimaryKey());
         self::assertFalse($table->getColumn('id')->getAutoincrement());
@@ -218,7 +221,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->introspectTable('text_blob_default_value');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('text_blob_default_value');
 
         self::assertNull($onlineTable->getColumn('def_text')->getDefault());
         self::assertNull($onlineTable->getColumn('def_text_null')->getDefault());
@@ -258,11 +261,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_column_charset');
+        [$id, $foo, $bar] = $this->schemaManager->introspectTableColumnsByUnquotedName('test_column_charset');
 
-        self::assertNull($columns['id']->getCharset());
-        self::assertEquals('ascii', $columns['foo']->getCharset());
-        self::assertEquals('latin1', $columns['bar']->getCharset());
+        self::assertNull($id->getCharset());
+        self::assertEquals('ascii', $foo->getCharset());
+        self::assertEquals('latin1', $bar->getCharset());
     }
 
     public function testAlterColumnCharset(): void
@@ -291,7 +294,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table = $this->schemaManager->introspectTable('test_alter_column_charset');
+        $table = $this->schemaManager->introspectTableByUnquotedName('test_alter_column_charset');
 
         self::assertEquals('ascii', $table->getColumn('col_text')->getCharset());
     }
@@ -325,7 +328,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         self::assertEquals(
             'ascii',
-            $this->schemaManager->introspectTable('test_column_charset_change')
+            $this->schemaManager->introspectTableByUnquotedName('test_column_charset_change')
                 ->getColumn('col_string')
                 ->getCharset(),
         );
@@ -368,13 +371,14 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_collation');
+        [$id, $text, $foo, $bar, $baz]
+            = $this->schemaManager->introspectTableColumnsByUnquotedName('test_collation');
 
-        self::assertNull($columns['id']->getCollation());
-        self::assertEquals('latin1_swedish_ci', $columns['text']->getCollation());
-        self::assertEquals('latin1_swedish_ci', $columns['foo']->getCollation());
-        self::assertEquals('utf8mb4_general_ci', $columns['bar']->getCollation());
-        self::assertInstanceOf(BlobType::class, $columns['baz']->getType());
+        self::assertNull($id->getCollation());
+        self::assertEquals('latin1_swedish_ci', $text->getCollation());
+        self::assertEquals('latin1_swedish_ci', $foo->getCollation());
+        self::assertEquals('utf8mb4_general_ci', $bar->getCollation());
+        self::assertInstanceOf(BlobType::class, $baz->getType());
     }
 
     public function testListLobTypeColumns(): void
@@ -425,41 +429,42 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $platform      = $this->connection->getDatabasePlatform();
-        $onlineColumns = $this->schemaManager->listTableColumns('lob_type_columns');
+        $platform = $this->connection->getDatabasePlatform();
+
+        [$colTinyText, $colText, $colMediumText, $colLongText, $colTinyBlob, $colBlob, $colMediumBlob, $colLongBlob]
+            = $this->schemaManager->introspectTableColumnsByUnquotedName('lob_type_columns');
 
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($table->getColumn('col_tinytext')->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_tinytext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($colTinyText->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($table->getColumn('col_text')->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_text']->toArray()),
+            $platform->getClobTypeDeclarationSQL($colText->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($table->getColumn('col_mediumtext')->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_mediumtext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($colMediumText->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($table->getColumn('col_longtext')->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_longtext']->toArray()),
+            $platform->getClobTypeDeclarationSQL($colLongText->toArray()),
         );
-
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($table->getColumn('col_tinyblob')->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_tinyblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($colTinyBlob->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($table->getColumn('col_blob')->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_blob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($colBlob->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($table->getColumn('col_mediumblob')->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_mediumblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($colMediumBlob->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($table->getColumn('col_longblob')->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_longblob']->toArray()),
+            $platform->getBlobTypeDeclarationSQL($colLongBlob->toArray()),
         );
     }
 
@@ -477,7 +482,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($offlineTable);
 
-        $onlineTable = $this->schemaManager->introspectTable('list_guid_table_column');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('list_guid_table_column');
 
         self::assertTrue(
             $this->schemaManager
@@ -511,12 +516,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_list_decimal_columns');
+        [$signed, $unsigned] = $this->schemaManager->introspectTableColumnsByUnquotedName('test_list_decimal_columns');
 
-        self::assertArrayHasKey('col', $columns);
-        self::assertArrayHasKey('col_unsigned', $columns);
-        self::assertFalse($columns['col']->getUnsigned());
-        self::assertTrue($columns['col_unsigned']->getUnsigned());
+        self::assertFalse($signed->getUnsigned());
+        self::assertTrue($unsigned->getUnsigned());
     }
 
     public function testListUnsignedFloatTypeColumns(): void
@@ -539,12 +542,13 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_unsigned_float_columns');
+        [$colUnsigned, $colSmallFloatUnsigned]
+            = $this->schemaManager->introspectTableColumnsByUnquotedName('test_unsigned_float_columns');
 
-        self::assertInstanceOf(FloatType::class, $columns['col_unsigned']->getType());
-        self::assertInstanceOf(SmallFloatType::class, $columns['col_smallfloat_unsigned']->getType());
-        self::assertTrue($columns['col_unsigned']->getUnsigned());
-        self::assertTrue($columns['col_smallfloat_unsigned']->getUnsigned());
+        self::assertInstanceOf(FloatType::class, $colUnsigned->getType());
+        self::assertInstanceOf(SmallFloatType::class, $colSmallFloatUnsigned->getType());
+        self::assertTrue($colUnsigned->getUnsigned());
+        self::assertTrue($colSmallFloatUnsigned->getUnsigned());
     }
 
     public function testConfigurableLengthColumns(): void
@@ -562,10 +566,10 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_configurable_length_columns');
+        [$column] = $this->schemaManager->introspectTableColumnsByUnquotedName('test_configurable_length_columns');
 
-        self::assertInstanceOf(BinaryType::class, $columns['col_binary']->getType());
-        self::assertSame(16, $columns['col_binary']->getLength());
+        self::assertInstanceOf(BinaryType::class, $column->getType());
+        self::assertSame(16, $column->getLength());
     }
 
     public function testJsonColumnType(): void
@@ -582,16 +586,17 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $columns = $this->schemaManager->listTableColumns('test_mysql_json');
+        [$column] = $this->schemaManager->introspectTableColumnsByUnquotedName('test_mysql_json');
 
-        self::assertInstanceOf(JsonType::class, $columns['col_json']->getType());
+        self::assertInstanceOf(JsonType::class, $column->getType());
     }
 
     public function testColumnDefaultCurrentTimestamp(): void
     {
         $platform = $this->connection->getDatabasePlatform();
 
-        $currentTimeStampSql = $platform->getCurrentTimestampSQL();
+        $currentTimeStamp    = new CurrentTimestamp();
+        $currentTimeStampSQL = $currentTimeStamp->toSQL($platform);
 
         $table = Table::editor()
             ->setUnquotedName('test_column_defaults_current_timestamp')
@@ -599,21 +604,21 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
                 Column::editor()
                     ->setUnquotedName('col_datetime')
                     ->setTypeName(Types::DATETIME_MUTABLE)
-                    ->setDefaultValue($currentTimeStampSql)
+                    ->setDefaultValue($currentTimeStamp)
                     ->create(),
                 Column::editor()
                     ->setUnquotedName('col_datetime_nullable')
                     ->setTypeName(Types::DATETIME_MUTABLE)
-                    ->setDefaultValue($currentTimeStampSql)
+                    ->setDefaultValue($currentTimeStamp)
                     ->create(),
             )
             ->create();
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->introspectTable('test_column_defaults_current_timestamp');
-        self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime')->getDefault());
-        self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime_nullable')->getDefault());
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('test_column_defaults_current_timestamp');
+        self::assertSame($currentTimeStampSQL, $onlineTable->getColumn('col_datetime')->getDefault());
+        self::assertSame($currentTimeStampSQL, $onlineTable->getColumn('col_datetime_nullable')->getDefault());
 
         self::assertTrue(
             $this->schemaManager
@@ -625,16 +630,9 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
     public function testColumnDefaultsAreValid(): void
     {
-        $currentTimeStampSql = $this->connection->getDatabasePlatform()->getCurrentTimestampSQL();
-
         $table = Table::editor()
             ->setUnquotedName('test_column_defaults_are_valid')
             ->setColumns(
-                Column::editor()
-                    ->setUnquotedName('col_datetime')
-                    ->setTypeName(Types::DATETIME_MUTABLE)
-                    ->setDefaultValue($currentTimeStampSql)
-                    ->create(),
                 Column::editor()
                     ->setUnquotedName('col_datetime_null')
                     ->setTypeName(Types::DATETIME_MUTABLE)
@@ -677,19 +675,15 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
             'INSERT INTO test_column_defaults_are_valid () VALUES()',
         );
 
-        $row = $this->connection->fetchAssociative(
-            'SELECT *, DATEDIFF(CURRENT_TIMESTAMP(), col_datetime) as diff_seconds FROM test_column_defaults_are_valid',
-        );
+        $row = $this->connection->fetchAssociative('SELECT * FROM test_column_defaults_are_valid');
         self::assertNotFalse($row);
 
-        self::assertInstanceOf(DateTime::class, DateTime::createFromFormat('Y-m-d H:i:s', $row['col_datetime']));
         self::assertNull($row['col_datetime_null']);
         self::assertSame('2012-12-12', $row['col_date']);
         self::assertSame('A', $row['col_string']);
         self::assertEquals(1, $row['col_int']);
         self::assertEquals(-1, $row['col_neg_int']);
         self::assertEquals('-2.300', $row['col_decimal']);
-        self::assertLessThan(5, $row['diff_seconds']);
     }
 
     /**
@@ -737,7 +731,9 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->introspectTable('test_column_defaults_current_time_and_date');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName(
+            'test_column_defaults_current_time_and_date',
+        );
 
         self::assertSame($currentTimestampSql, $onlineTable->getColumn('col_datetime')->getDefault());
         self::assertSame($currentDateSql, $onlineTable->getColumn('col_date')->getDefault());
@@ -768,7 +764,7 @@ PARTITION BY HASH (col1)
 SQL;
 
         $this->connection->executeStatement($sql);
-        $onlineTable = $this->schemaManager->introspectTable('test_table_metadata');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('test_table_metadata');
 
         self::assertEquals('InnoDB', $onlineTable->getOption('engine'));
         self::assertEquals('utf8mb4_general_ci', $onlineTable->getOption('collation'));
@@ -785,7 +781,7 @@ SQL;
         $this->connection->executeStatement('DROP TABLE IF EXISTS test_table_empty_metadata');
 
         $this->connection->executeStatement('CREATE TABLE test_table_empty_metadata(col1 INT NOT NULL)');
-        $onlineTable = $this->schemaManager->introspectTable('test_table_empty_metadata');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('test_table_empty_metadata');
 
         self::assertNotEmpty($onlineTable->getOption('engine'));
         // collation could be set to default or not set, information_schema indicate a possibly null value
@@ -821,7 +817,7 @@ SQL;
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->introspectTable('test_column_introspection');
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('test_column_introspection');
 
         $diff = $this->schemaManager->createComparator()->compareTables($table, $onlineTable);
 
@@ -838,7 +834,7 @@ SQL;
 
         $this->expectException(DatabaseRequired::class);
 
-        $schemaManager->listTableColumns('users');
+        $schemaManager->introspectTableColumnsByUnquotedName('users');
     }
 
     public function testSchemaDiffWithCustomColumnTypeWhileDatabaseTypeDiffers(): void
@@ -875,6 +871,29 @@ SQL;
         );
     }
 
+    public function testMigrateOldBoolean(): void
+    {
+        $this->connection->executeStatement('DROP TABLE IF EXISTS table_with_old_boolean');
+        $this->connection->executeStatement(
+            'CREATE TABLE table_with_old_boolean (val TINYINT(1) NOT NULL)',
+        );
+
+        $onlineTable = $this->schemaManager->introspectTableByUnquotedName('table_with_old_boolean');
+        $targetTable = Table::editor()
+            ->setUnquotedName('table_with_old_boolean')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('val')
+                    ->setTypeName(Types::BOOLEAN)
+                    ->create(),
+            )
+            ->create();
+
+        $diff = $this->schemaManager->createComparator()->compareTables($onlineTable, $targetTable);
+
+        self::assertTrue($diff->isEmpty(), 'Tables should be identical.');
+    }
+
     public function getExpectedDefaultSchemaName(): ?string
     {
         return null;
