@@ -7,6 +7,8 @@ namespace Doctrine\DBAL\Tests\Functional\Schema\SQLite;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\AbstractSchemaManager;
+use Doctrine\DBAL\Schema\Column;
+use Doctrine\DBAL\Schema\ColumnEditor;
 use Doctrine\DBAL\Schema\Comparator;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\Functional\Schema\ComparatorTestUtils;
@@ -35,11 +37,24 @@ final class ComparatorTest extends FunctionalTestCase
 
     public function testChangeTableCollation(): void
     {
-        $table  = new Table('comparator_test');
-        $column = $table->addColumn('id', Types::STRING);
+        $table = Table::editor()
+            ->setUnquotedName('comparator_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::STRING)
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
 
-        $column->setPlatformOption('collation', 'NOCASE');
+        $table = $table->edit()
+            ->modifyColumnByUnquotedName('id', static function (ColumnEditor $editor): void {
+                $editor->setCollation('NOCASE');
+            })
+            ->create();
+
         ComparatorTestUtils::assertDiffNotEmpty($this->connection, $this->comparator, $table);
     }
 }
