@@ -1,9 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Functional\Schema\Types;
 
 use Doctrine\DBAL\Platforms\AbstractPlatform;
-use Doctrine\DBAL\Types\ConversionException;
+use Doctrine\DBAL\Types\Exception\InvalidFormat;
+use Doctrine\DBAL\Types\Exception\InvalidType;
 use Doctrine\DBAL\Types\Type;
 use InvalidArgumentException;
 
@@ -13,14 +16,6 @@ class MoneyType extends Type
 {
     public const NAME = 'money';
 
-    /**
-     * {@inheritDoc}
-     */
-    public function getName()
-    {
-        return self::NAME;
-    }
-
     /**
      * {@inheritDoc}
      */
@@ -29,44 +24,33 @@ class MoneyType extends Type
         return $platform->getDecimalTypeDeclarationSQL($column);
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function convertToDatabaseValue($value, AbstractPlatform $platform): ?string
+    public function convertToDatabaseValue(mixed $value, AbstractPlatform $platform): ?string
     {
         if ($value === null) {
-            return $value;
+            return null;
         }
 
         if ($value instanceof Money) {
-            return $value->__toString();
+            return (string) $value;
         }
 
-        throw ConversionException::conversionFailedInvalidType($value, $this->getName(), ['null', Money::class]);
+        throw InvalidType::new($value, self::NAME, ['null', Money::class]);
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public function convertToPHPValue($value, AbstractPlatform $platform): ?Money
+    public function convertToPHPValue(mixed $value, AbstractPlatform $platform): ?Money
     {
         if ($value === null || $value instanceof Money) {
             return $value;
         }
 
         if (! is_string($value)) {
-            throw ConversionException::conversionFailedInvalidType($value, $this->getName(), ['null', 'string']);
+            throw InvalidType::new($value, self::NAME, ['null', 'string']);
         }
 
         try {
             return new Money($value);
         } catch (InvalidArgumentException $e) {
-            throw ConversionException::conversionFailedFormat($value, $this->getName(), Money::class, $e);
+            throw InvalidFormat::new($value, self::NAME, Money::class, $e);
         }
     }
-
-    public function requiresSQLCommentHint(AbstractPlatform $platform): bool
-    {
-        return true;
-    }
 }
