@@ -11,6 +11,7 @@ use Doctrine\DBAL\Driver\SQLSrv;
 use Doctrine\DBAL\Exception;
 use Doctrine\DBAL\Exception\DriverException;
 use Doctrine\DBAL\ParameterType;
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
@@ -20,6 +21,8 @@ use Error;
 
 use function base64_decode;
 use function get_debug_type;
+use function ini_restore;
+use function ini_set;
 use function sprintf;
 use function stream_get_contents;
 
@@ -27,12 +30,30 @@ class StatementTest extends FunctionalTestCase
 {
     protected function setUp(): void
     {
-        $table = new Table('stmt_test');
-        $table->addColumn('id', Types::INTEGER);
-        $table->addColumn('name', Types::TEXT, ['notnull' => false]);
+        $table = Table::editor()
+            ->setUnquotedName('stmt_test')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('id')
+                    ->setTypeName(Types::INTEGER)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('name')
+                    ->setTypeName(Types::TEXT)
+                    ->setNotNull(false)
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
     }
 
+    protected function tearDown(): void
+    {
+        ini_restore('memory_limit');
+        ini_restore('error_reporting');
+    }
+
     public function testStatementIsReusableAfterFreeingResult(): void
     {
         if (TestUtil::isDriverOneOf('pdo_oci')) {
@@ -62,9 +83,21 @@ class StatementTest extends FunctionalTestCase
             self::markTestIncomplete("PDO_OCI doesn't support fetching blobs via PDOStatement::fetchAll()");
         }
 
-        $table = new Table('stmt_longer_results');
-        $table->addColumn('param', Types::STRING, ['length' => 24]);
-        $table->addColumn('val', Types::TEXT);
+        $table = Table::editor()
+            ->setUnquotedName('stmt_longer_results')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('param')
+                    ->setTypeName(Types::STRING)
+                    ->setLength(24)
+                    ->create(),
+                Column::editor()
+                    ->setUnquotedName('val')
+                    ->setTypeName(Types::TEXT)
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($table);
 
         $row1 = [
@@ -102,10 +135,19 @@ class StatementTest extends FunctionalTestCase
 
         // make sure memory limit is large enough to not cause false positives,
         // but is still not enough to store a LONGBLOB of the max possible size
-        $this->iniSet('memory_limit', '4G');
+        ini_set('memory_limit', '4G');
+
+        $table = Table::editor()
+            ->setUnquotedName('stmt_long_blob')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('contents')
+                    ->setTypeName(Types::BLOB)
+                    ->setLength(0xFFFFFFFF)
+                    ->create(),
+            )
+            ->create();
 
-        $table = new Table('stmt_long_blob');
-        $table->addColumn('contents', Types::BLOB, ['length' => 0xFFFFFFFF]);
         $this->dropAndCreateTable($table);
 
         $contents = base64_decode(<<<'EOF'
@@ -286,7 +328,7 @@ EOF
         } else {
             // we want to make sure the exception is thrown by the DBAL code, not by PHPUnit due to a PHP-level error,
             // but the wrapper connection wraps everything in a DBAL exception
-            $this->iniSet('error_reporting', '0');
+            ini_set('error_reporting', '0');
 
             $this->expectException(Exception::class);
         }
