@@ -407,14 +407,19 @@ SQL
         );
     }
 
+    /** @param non-negative-int $cacheSize */
     #[DataProvider('dataCreateSequenceWithCache')]
     public function testCreateSequenceWithCache(int $cacheSize, string $expectedSql): void
     {
-        $sequence = new Sequence('foo', 1, 1, $cacheSize);
+        $sequence = Sequence::editor()
+            ->setUnquotedName('foo')
+            ->setCacheSize($cacheSize)
+            ->create();
+
         self::assertStringContainsString($expectedSql, $this->platform->getCreateSequenceSQL($sequence));
     }
 
-    /** @return mixed[][] */
+    /** @return iterable<array{non-negative-int, string}> */
     public static function dataCreateSequenceWithCache(): iterable
     {
         return [
@@ -563,7 +568,7 @@ SQL
             ->create();
 
         self::assertTrue($table->isQuoted());
-        self::assertEquals('test', $table->getName());
+        self::assertEquals('test', $table->getObjectName()->getUnqualifiedName()->getValue());
         self::assertEquals('"test"', $table->getQuotedName($this->platform));
 
         $sql = $this->platform->getCreateTableSQL($table);
@@ -651,4 +656,13 @@ EOD;
             'multiple values' => [['foo', 'bar1'], 'VARCHAR2(4)'],
         ];
     }
+
+    /** @return array<string, array{array<string>, int, string}> */
+    public static function getEnumDeclarationWithLengthSQLProvider(): array
+    {
+        return [
+            'single value and bigger length' => [['foo'], 42, 'VARCHAR2(42)'],
+            'multiple values and bigger length' => [['foo', 'bar1'], 42, 'VARCHAR2(42)'],
+        ];
+    }
 }
