@@ -7,16 +7,14 @@ namespace Doctrine\DBAL\Tests\Portability;
 use Doctrine\DBAL\Driver\Result as DriverResult;
 use Doctrine\DBAL\Portability\Converter;
 use Doctrine\DBAL\Portability\Result;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 
 class ResultTest extends TestCase
 {
-    /**
-     * @param mixed $return
-     *
-     * @dataProvider fetchProvider
-     */
-    public function testFetch(string $source, callable $fetch, $return): void
+    /** @param non-empty-string $source */
+    #[DataProvider('fetchProvider')]
+    public function testFetch(string $source, callable $fetch, mixed $return): void
     {
         $driverResult = $this->createMock(DriverResult::class);
         $driverResult->expects(self::once())
@@ -49,7 +47,7 @@ class ResultTest extends TestCase
 
         yield 'one' => [
             'fetchOne',
-            static function (Result $result) {
+            static function (Result $result): mixed {
                 return $result->fetchOne();
             },
             'bar',
