@@ -17,6 +17,7 @@ use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Platforms\SQLitePlatform;
 use Doctrine\DBAL\Schema\DefaultSchemaManagerFactory;
 use InvalidArgumentException;
+use PDO;
 use PHPUnit\Framework\Assert;
 
 use function array_map;
@@ -241,6 +242,11 @@ class TestUtil
         return in_array($params['driver'], $names, true);
     }
 
+    public static function isPdoStringifyFetchesEnabled(): bool
+    {
+        return (self::getConnectionParams()['driverOptions'][PDO::ATTR_STRINGIFY_FETCHES] ?? false) === true;
+    }
+
     /**
      * Generates a query that will return the given rows without the need to create a temporary table.
      *
