@@ -1,12 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use DateTime;
-use DateTimeImmutable;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\ConversionException;
 use Doctrine\DBAL\Types\Type;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use stdClass;
@@ -16,18 +18,16 @@ use function date_default_timezone_set;
 
 abstract class BaseDateTypeTestCase extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    protected AbstractPlatform $platform;
-
+    protected AbstractPlatform&MockObject $platform;
     protected Type $type;
+
+    /** @var non-empty-string */
     private string $currentTimezone;
 
     protected function setUp(): void
     {
         $this->platform        = $this->createMock(AbstractPlatform::class);
         $this->currentTimezone = date_default_timezone_get();
-
-        self::assertInstanceOf(Type::class, $this->type);
     }
 
     protected function tearDown(): void
@@ -40,12 +40,8 @@ abstract class BaseDateTypeTestCase extends TestCase
         self::assertIsString($this->type->convertToDatabaseValue(new DateTime(), $this->platform));
     }
 
-    /**
-     * @param mixed $value
-     *
-     * @dataProvider invalidPHPValuesProvider
-     */
-    public function testInvalidTypeConversionToDatabaseValue($value): void
+    #[DataProvider('invalidPHPValuesProvider')]
+    public function testInvalidTypeConversionToDatabaseValue(mixed $value): void
     {
         $this->expectException(ConversionException::class);
 
@@ -64,28 +60,6 @@ abstract class BaseDateTypeTestCase extends TestCase
         self::assertSame($date, $this->type->convertToPHPValue($date, $this->platform));
     }
 
-    /**
-     * Note that while \@see \DateTimeImmutable is supposed to be handled
-     * by @see \Doctrine\DBAL\Types\DateTimeImmutableType, previous DBAL versions handled it just fine.
-     * This test is just in place to prevent further regressions, even if the type is being misused
-     */
-    public function testConvertDateTimeImmutableToPHPValue(): void
-    {
-        $date = new DateTimeImmutable('now');
-
-        self::assertSame($date, $this->type->convertToPHPValue($date, $this->platform));
-    }
-
-    /**
-     * Note that while \@see \DateTimeImmutable is supposed to be handled
-     * by @see \Doctrine\DBAL\Types\DateTimeImmutableType, previous DBAL versions handled it just fine.
-     * This test is just in place to prevent further regressions, even if the type is being misused
-     */
-    public function testDateTimeImmutableConvertsToDatabaseValue(): void
-    {
-        self::assertIsString($this->type->convertToDatabaseValue(new DateTimeImmutable(), $this->platform));
-    }
-
     /** @return mixed[][] */
     public static function invalidPHPValuesProvider(): iterable
     {
