@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\DBAL\Tests\Types;
 
 use DateTime;
@@ -7,29 +9,21 @@ use DateTimeImmutable;
 use Doctrine\DBAL\ParameterType;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\ConversionException;
-use Doctrine\DBAL\Types\Types;
 use Doctrine\DBAL\Types\VarDateTimeImmutableType;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 
 class VarDateTimeImmutableTypeTest extends TestCase
 {
-    /** @var AbstractPlatform&MockObject */
-    private AbstractPlatform $platform;
-
+    private AbstractPlatform&MockObject $platform;
     private VarDateTimeImmutableType $type;
 
     protected function setUp(): void
     {
-        $this->platform = $this->getMockForAbstractClass(AbstractPlatform::class);
+        $this->platform = $this->createMock(AbstractPlatform::class);
         $this->type     = new VarDateTimeImmutableType();
     }
 
-    public function testReturnsName(): void
-    {
-        self::assertSame(Types::DATETIME_IMMUTABLE, $this->type->getName());
-    }
-
     public function testReturnsBindingType(): void
     {
         self::assertSame(ParameterType::STRING, $this->type->getBindingType());
@@ -37,7 +31,11 @@ class VarDateTimeImmutableTypeTest extends TestCase
 
     public function testConvertsDateTimeImmutableInstanceToDatabaseValue(): void
     {
-        $date = $this->getMockBuilder(DateTimeImmutable::class)->getMock();
+        $this->platform->expects(self::any())
+            ->method('getDateTimeFormatString')
+            ->willReturn('Y-m-d H:i:s');
+
+        $date = $this->createMock(DateTimeImmutable::class);
 
         $date->expects(self::once())
             ->method('format')
@@ -88,9 +86,4 @@ class VarDateTimeImmutableTypeTest extends TestCase
 
         $this->type->convertToPHPValue('invalid date-ish string', $this->platform);
     }
-
-    public function testRequiresSQLCommentHint(): void
-    {
-        self::assertTrue($this->type->requiresSQLCommentHint($this->platform));
-    }
 }
